@@ -11,9 +11,13 @@ DATA_DEF = {
 #: Optional QPImage attributes
 OTHER_DEF = {
     "angle": "tomographic acquisition angle [rad]",
+    "date": "acquisition date 'YYYY-MM-DD'",
     "device": "imaging device used",
     "focus": "focus position [m]",
     "identifier": "image identifier",
+    "numerical aperture": "numerical aperture",
+    "pos x": "x position [m]",
+    "pos y": "y position [m]",
     "qpimage version": "qpimage software version used",
     "sim center": "simulation: center of object [px]",
     "sim index": "simulation: refractive index of object",
@@ -31,7 +35,7 @@ META_KEYS = DATA_KEYS + OTHER_KEYS
 
 
 class MetaDataMissingError(BaseException):
-    """Raised when meta data is missing"""
+    """Raised when metadata is missing"""
     pass
 
 
@@ -61,10 +65,11 @@ class MetaDict(collections.UserDict):
 
     def __getitem__(self, *args, **kwargs):
         if args[0] not in self and args[0] in self.valid_keys:
-            msg = "No meta data was defined for '{}'!".format(args[0]) \
-                  + "Please make sure you passed the dictionary `meta_data` " \
-                  + "when you loaded your data."
-            raise MetaDataMissingError(msg)
+            raise MetaDataMissingError(
+                f"No meta data was defined for '{args[0]}'! "
+                + "Please make sure you passed the dictionary `meta_data` "
+                + "when you loaded your data."
+                )
         elif args[0] not in self:
             msg = "Unknown meta key: '{}'!".format(args[0])
             raise KeyError(msg)
